 /*  Variable Frequency Drive with AVR ATMega 88/168/328    */
/*! \file *********************************************************************
 *
 *
 *      This file contains the table definitions used for sine control.
 *
 * \par Based on Application note:
 *      AVR447: Sinusoidal driving of three-phase permanent motor using
 *      ATmega48/88/168
 *
 * \par Documentation
 *      For comprehensive code documentation, supported compilers, compiler
 *      settings and supported devices see readme.html
 *
 * \author
 *      Atmel Corporation: http://www.atmel.com \n
 *      Support email: avr@atmel.com
 * 	by Matthias Schoeldgen - DC7UR 
 * $Name: RELEASE_1_0 $
 * $Revision: 1.4 $
 * $RCSfile: PMSMtables.h,v $
 * $Date: 2010/04/16 11:57:20 $  \n
 ******************************************************************************/

#ifndef _PMSM_TABLES_H_
#define _PMSM_TABLES_H_
#define MOTOR_2PHASEN
#ifdef MOTOR_2PHASEN
const PROGMEM uint8_t sineTable[SINE_TABLE_LENGTH * 3] = {
0,       255,    0b00000000,                //  0         //0   90
8,       255,    0b00000000,                       //  8,    
17,      254,    0b00000000,                       //  17,
25,      254,    0b00000000,                       //  25,
33,      253,    0b00000000,                       //  33, 
42,      252,    0b00000000,                       //  42,
50,      250,    0b00000000,                       //  50,
58,      248,    0b00000000,                       //  58,
66,      246,    0b00000000,                       //  66,
74,      244,    0b00000000,                       //  74,
82,      241,    0b00000000,                       //  82,                        
90,      239,    0b00000000,                       //  90,
98,      236,    0b00000000,                       //  98,
105,     232,    0b00000000,                       // 105,
113,     229,    0b00000000,                       // 113,
120,     225,    0b00000000,                       // 120,
128,     221,    0b00000000,		// 0x10            128,    30  120
135,     217,    0b00000000,                       // 135,
142,     212,    0b00000000,                       // 142,
149,     207,    0b00000000,                       // 149,
155,     202,    0b00000000,                       // 155,
162,     197,    0b00000000,                       // 162,                    
168,     192,    0b00000000,                       // 168,
174,     186,    0b00000000,                       // 174,
180,     180,    0b00000000,                       // 180,
186,     174,    0b00000000,                       // 186,
192,     168,    0b00000000,                       // 192,
197,     162,    0b00000000,                       // 197,
202,     155,    0b00000000,                       // 202,
207,     149,    0b00000000,                       // 207,
212,     142,    0b00000000,                        // 212,                       
217,     135,    0b00000000,                       // 217,
221,     128,    0b00000000,		// 0x20            221,    60    150
225,     120,    0b00000000,                       // 225,
229,     113,    0b00000000,                       // 229,
232,     105,    0b00000000,                       // 232,
236,     98,     0b00000000,                       // 236,
239,     90,     0b00000000,                       // 239,
241,     82,     0b00000000,                       // 241,
244,     74,     0b00000000,                       // 244,
246,     66,     0b00000000,                       // 246,
248,     58,     0b00000000,                       // 248,
250,     50,     0b00000000,                       // 250,
252,     42,     0b00000000,                       // 252,
253,     33,     0b00000000,                       // 253,
254,     25,     0b00000000,                       // 254,
254,     17,     0b00000000,                       // 254,
255,     8,      0b00000000,                       // 255,
255,     0,      0b00000001,	    // 0x30            255,    //90   180  
255,     8,      0b00000001,                       // 255,
254,     17,     0b00000001,                       // 254,
254,     25,     0b00000001,                       // 254,
253,     33,     0b00000001,                        // 253,
252,     42,     0b00000001,                        // 252,
250,     50,     0b00000001,                        // 250,
248,     58,     0b00000001,                        // 248,
246,     66,     0b00000001,                        // 246,
244,     74,     0b00000001,                        // 244,
241,     82,     0b00000001,                        // 241,
239,     90,     0b00000001,                        // 239,
236,     98,     0b00000001,                        // 236,
232,     105,    0b00000001,                        // 232,
229,     113,    0b00000001,                        // 229,
225,     120,    0b00000001,                         // 225,
221,     128,    0b00000001,		// 0x40                221,   120  210 
217,     135,    0b00000001,                         // 217,
212,     142,    0b00000001,                         // 212,
207,     149,    0b00000001,                         // 207,
202,     155,    0b00000001,                         // 202,
197,     162,    0b00000001,                         // 197,
192,     168,    0b00000001,                         // 192,
186,     174,    0b00000001,                         // 186,
180,     180,    0b00000001,                         // 180,
174,     186,    0b00000001,                         // 174,
168,     192,    0b00000001,                         // 168,
162,     197,    0b00000001,                         // 162,
155,     202,    0b00000001,                         // 155,
149,     207,    0b00000001,                         // 149,
142,     212,    0b00000001,                         // 142,
135,     217,    0b00000001,                         // 135,
128,     221,    0b00000001,		// 0x50             // 128,    150   240
120,     225,    0b00000001,                         // 120,
113,     229,    0b00000001,                         // 113,
105,     232,    0b00000001,                         // 105,
98,      236,    0b00000001,                         //  98,
90,      239,    0b00000001,                         //  90,
82,      241,    0b00000001,                         //  82,
74,      244,    0b00000001,                         //  74,
66,      246,    0b00000001,                         //  66,
58,      248,    0b00000001,                         //  58,
50,      250,    0b00000001,                         //  50,
42,      252,    0b00000001,                         //  42,
33,      253,    0b00000001,                         //  33,
25,      254,    0b00000001,                         //  25,
17,      254,    0b00000001,                         //  17,
8,       255,    0b00000001,                         //   8,
0,       255,    0b00000011,		// 0x60                  180 270
8,       255,    0b00000011,                         //  -8,
17,      254,    0b00000011,                         // -17,
25,      254,    0b00000011,                         // -25,
33,      253,    0b00000011,                         // -33,
42,      252,    0b00000011,                         // -42,
50,      250,    0b00000011,                         // -50,
58,      248,    0b00000011,                         // -58,
66,      246,    0b00000011,                         // -66,
74,      244,    0b00000011,                         // -74,
82,      241,    0b00000011,                         // -82,
90,      239,    0b00000011,                         // -90,
98,      236,    0b00000011,                         // -98,
105,     232,    0b00000011,                         //-105,
113,     229,    0b00000011,                         //-113,
120,     225,    0b00000011,                         //-120,
128,     221,    0b00000011,		//0x70              //-128, 210  300
135,     217,    0b00000011,                         //-135,
142,     212,    0b00000011,                         //-142,
149,     207,    0b00000011,                         //-149,
155,     202,    0b00000011,                         //-155,
162,     197,    0b00000011,                         //-162,
168,     192,    0b00000011,                         //-168,
174,     186,    0b00000011,                         //-174,
180,     180,    0b00000011,                         //-180,
186,     174,    0b00000011,                         //-186,
192,     168,    0b00000011,                         //-192,
197,     162,    0b00000011,                         //-197,
202,     155,    0b00000011,                         //-202,
207,     149,    0b00000011,                         //-207,
212,     142,    0b00000011,                         //-212,
217,     135,    0b00000011,                         //-217,
221,     128,    0b00000011,		// 0x80             //-221,  240   330
225,     120,    0b00000011,                         //-225,
229,     113,    0b00000011,                        //-229,
232,     105,    0b00000011,                        //-232,
236,      98,    0b00000011,                        //-236,
239,      90,    0b00000011,                        //-239,
241,      82,    0b00000011,                        //-241,
244,      74,    0b00000011,                        //-244,
246,      66,    0b00000011,                        //-246,
248,      58,    0b00000011,                        //-248,
250,      50,    0b00000011,                        //-250,
252,      42,    0b00000011,                        //-252,
253,      33,    0b00000011,                        //-253,
254,      25,    0b00000011,                       //-254,
254,      17,    0b00000011,                       //-254,
255,       8,    0b00000011,                       //-255,
255,       0,    0b00000010,		// 0x90         //-255, 270  360-0
255,       8,    0b00000010,                       //-255,
254,      17,    0b00000010,                       //-254,
254,      25,    0b00000010,                       //-254,
253,      33,    0b00000010,                       //-253,
252,      42,    0b00000010,                       //-252,
250,      50,    0b00000010,                       //-250,
248,      58,    0b00000010,                       //-248,
246,      66,    0b00000010,                       //-246,
244,      74,    0b00000010,                       //-244,
241,      82,    0b00000010,                       //-241,
239,      90,    0b00000010,                       //-239,
236,      98,    0b00000010,                       //-236,
232,     105,    0b00000010,                       //-232,
229,     113,    0b00000010,                       //-229,
225,     120,    0b00000010,                       //-225,
221,     128,    0b00000010,		// 0xa0         //-221,    300  30 
217,     135,    0b00000010,                       //-217,
212,     142,    0b00000010,                       //-212,
207,     149,    0b00000010,                       //-207,
202,     155,    0b00000010,                       //-202,
197,     162,    0b00000010,                       //-197,
192,     168,    0b00000010,                       //-192,
186,     174,    0b00000010,                       //-186,
180,     180,    0b00000010,                       //-180,
174,     186,    0b00000010,                       //-174,
168,     192,    0b00000010,                       //-168,
162,     197,    0b00000010,                       //-162,
155,     202,    0b00000010,                       //-155,
149,     207,    0b00000010,                       //-149,
142,     212,    0b00000010,                       //-142,
135,     217,    0b00000010,                       //-135,
128,     221,    0b00000010,		// 0xb0         //-128,  330  60
120,     225,    0b00000010,                       //-120,
113,     229,    0b00000010,                       //-113,
105,     232,    0b00000010,                       //-105,
98,      236,    0b00000010,                       // -98,
90,      239,    0b00000010,                       // -90,
82,      241,    0b00000010,                       // -82,                       
74,      244,    0b00000010,                       // -74,
66,      246,    0b00000010,                       // -66,
58,      248,    0b00000010,                       // -58,
50,      250,    0b00000010,                       // -50,
42,      252,    0b00000010,                       // -42,
33,      253,    0b00000010,                       // -33,
25,      254,    0b00000010,                       // -25,
17,      254,    0b00000010,                       // -17,
8,       255,    0b00000010		// 0xbf            //  -8,   
};	
#else

#ifdef PURE_SINE_DRIVE
const PROGMEM uint8_t sineTable[SINE_TABLE_LENGTH * 3] = {
128,  17,  238,    
132,  15,  236,    
136,  13,  234,    
140,  11,  231,    
144,  10,  229,    
148,  8,   226,    
152,  7,   223,    
156,  5,   221,    
160,  4,   218,    
165,  3,   215,    
168,  2,   212,    
172,  2,   208,    
176,  1,   205,    
180,  1,   202,    
184,  0,   198,    
188,  0,   195,    
191,  0,   191,    
195,  0,   188,    
198,  0,   184,    
202,  1,   180,    
205,  1,   176,    
208,  2,   172,    
212,  2,   168,    
215,  3,   165,    
218,  4,   160,    
221,  5,   156,    
223,  7,   152,    
226,  8,   148,    
229,  10,  144,    
231,  11,  140,    
234,  13,  136,    
236,  15,  132,    
238,  17,  128,    
240,  19,  123,    
242,  21,  119,    
244,  24,  115,    
245,  26,  111,    
247,  29,  107,    
248,  32,  103,    
250,  34,  99,     
251,  37,  95,     
252,  40,  90,     
253,  43,  87,     
253,  47,  83,     
254,  50,  79,     
254,  53,  75,     
255,  57,  71,     
255,  60,  67,     
255,  64,  64,     
255,  67,  60,     
255,  71,  57,     
254,  75,  53,     
254,  79,  50,     
253,  83,  47,     
253,  87,  43,     
252,  90,  40,     
251,  95,  37,     
250,  99,  34,     
248, 103,  32,     
247, 107,  29,     
245, 111,  26,     
244, 115,  24,     
242, 119,  21,     
240, 123,  19,                     // 
238, 128,  17, 					//
236, 132,  15,     
234, 136,  13,     
231, 140,  11,     
229, 144,  10,     
226, 148,  8,      
223, 152,  7,      
221, 156,  5,      
218, 160,  4,      
215, 165,  3,      
212, 168,  2,      
208, 172,  2,      
205, 176,  1,      
202, 180,  1,      
198, 184,  0,      
195, 188,  0,      
191, 191,  0,      
188, 195,  0,      
184, 198,  0,      
180, 202,  1,      
176, 205,  1,      
172, 208,  2,      
168, 212,  2,      
165, 215,  3,      
160, 218,  4,      
156, 221,  5,      
152, 223,  7,      
148, 226,  8,      
144, 229,  10,     
140, 231,  11,     
136, 234,  13,     
132, 236,  15,     
128, 238,  17,     
123, 240,  19,     
119, 242,  21,     
115, 244,  24,     
111, 245,  26,     
107, 247,  29,     
103, 248,  32,     
99,  250,  34,     
95,  251,  37,     
90,  252,  40,     
87,  253,  43,     
83,  253,  47,     
79,  254,  50,     
75,  254,  53,     
71,  255,  57,     
67,  255,  60,     
64,  255,  64,     
60,  255,  67,     
57,  255,  71,     
53,  254,  75,     
50,  254,  79,     
47,  253,  83,     
43,  253,  87,     
40,  252,  90,     
37,  251,  95,     
34,  250,  99,     
32,  248,  103,    
29,  247,  107,    
26,  245,  111,    
24,  244,  115,    
21,  242,  119,    
19,  240,  123,    
17,  238,  128,                              // 
15,  236,  132,     
13,  234,  136,     
11,  231,  140,     
10,  229,  144,     
8,   226,  148,     
7,   223,  152,     
5,   221,  156,     
4,   218,  160,     
3,   215,  165,     
2,   212,  168,     
2,   208,  172,     
1,   205,  176,     
1,   202,  180,     
0,   198,  184,     
0,   195,  188,     
0,   191,  191,     
0,   188,  195,     
0,   184,  198,     
1,   180,  202,     
1,   176,  205,     
2,   172,  208,     
2,   168,  212,     
3,   165,  215,     
4,   160,  218,     
5,   156,  221,     
7,   152,  223,     
8,   148,  226,     
10,  144,  229,     
11,  140,  231,     
13,  136,  234,     
15,  132,  236,     
17,  128,  238,     
19,  123,  240,     
21,  119,  242,     
24,  115,  244,     
26,  111,  245,     
29,  107,  247,     
32,  103,  248,     
34,  99,   250,     
37,  95,   251,     
40,  90,   252,     
43,  87,   253,     
47,  83,   253,     
50,  79,   254,     
53,  75,   254,     
57,  71,   255,     
60,  67,   255,     
64,  64,   255,     
67,  60,   255,     
71,  57,   255,     
75,  53,   254,     
79,  50,   254,     
83,  47,   253,     
87,  43,   253,     
90,  40,   252,     
95,  37,   251,     
99,  34,   250,     
103, 32,   248,     
107, 29,   247,     
111, 26,   245,     
115, 24,   244,     
119, 21,   242,     
123, 19,   240      
};    
#else 
/*!   \brief Sine wave modulation table
 *    
 *    Table containing modulation values for all three phases.
 *    The table is organized as [U1,  V1, W1, U2, V2, W2, ...]
 *    for forward driving, and [U1, W1, V1, U2, W2, V2, ...]
 *    for reverse driving.
 */         
const PROGMEM uint8_t sineTable[SINE_TABLE_LENGTH * 3] = {
0,       0,      221,		// Offset 0 
8,       0,      225,
17,      0,      229,
25,      0,      232,
33,      0,      236,
42,      0,      239,
50,      0,      241,
58,      0,      244,
66,      0,      246,
74,      0,      248,
82,      0,      250,
90,      0,      252,
98,      0,      253,
105,     0,      254,
113,     0,      254,
120,     0,      255,		
128,     0,      255,		// 0x10
135,     0,      255,
142,     0,      254,
149,     0,      254,
155,     0,      253,
162,     0,      252,
168,     0,      250,
174,     0,      248,
180,     0,      246,
186,     0,      244,
192,     0,      241,
197,     0,      239,
202,     0,      236,
207,     0,      232,
212,     0,      229,
217,     0,      225,
221,     0,      221,		// 0x20
225,     0,      217,
229,     0,      212,
232,     0,      207,
236,     0,      202,
239,     0,      197,
241,     0,      192,
244,     0,      186,
246,     0,      180,
248,     0,      174,
250,     0,      168,
252,     0,      162,
253,     0,      155,
254,     0,      149,
254,     0,      142,
255,     0,      135,
255,     0,      127,		// 0x30
255,     0,      120,
254,     0,      113,
254,     0,      105,
253,     0,      98,
252,     0,      90,
250,     0,      82,
248,     0,      74,
246,     0,      66,
244,     0,      58,
241,     0,      50,
239,     0,      42,
236,     0,      33,
232,     0,      25,
229,     0,      17,
225,     0,      8,
221,     0,      0,		// 0x40
225,     8,      0,
229,     17,     0,
232,     25,     0,
236,     33,     0,
239,     42,     0,
241,     50,     0,
244,     58,     0,
246,     66,     0,
248,     74,     0,
250,     82,     0,
252,     90,     0,
253,     98,     0,
254,     105,    0,
254,     113,    0,
255,     120,    0,
255,     127,    0,		// 0x50
255,     135,    0,
254,     142,    0,
254,     149,    0,
253,     155,    0,
252,     162,    0,
250,     168,    0,
248,     174,    0,
246,     180,    0,
244,     186,    0,
241,     192,    0,
239,     197,    0,
236,     202,    0,
232,     207,    0,
229,     212,    0,
225,     217,    0,
221,     221,    0,		// 0x60
217,     225,    0,
212,     229,    0,
207,     232,    0,
202,     236,    0,
197,     239,    0,
192,     241,    0,
186,     244,    0,
180,     246,    0,
174,     248,    0,
168,     250,    0,
162,     252,    0,
155,     253,    0,
149,     254,    0,
142,     254,    0,
135,     255,    0,
128,     255,    0,		//0x70
120,     255,    0,
113,     254,    0,
105,     254,    0,
98,      253,    0,
90,      252,    0,
82,      250,    0,
74,      248,    0,
66,      246,    0,
58,      244,    0,
50,      241,    0,
42,      239,    0,
33,      236,    0,
25,      232,    0,
17,      229,    0,
8,       225,    0,
0,       221,    0,		// 0x80
0,       225,    8,
0,       229,    17,
0,       232,    25,
0,       236,    33,
0,       239,    42,
0,       241,    50,
0,       244,    58,
0,       246,    66,
0,       248,    74,
0,       250,    82,
0,       252,    90,
0,       253,    98,
0,       254,    105,
0,       254,    113,
0,       255,    120,
0,       255,    128,		// 0x90
0,       255,    135,
0,       254,    142,
0,       254,    149,
0,       253,    155,
0,       252,    162,
0,       250,    168,
0,       248,    174,
0,       246,    180,
0,       244,    186,
0,       241,    192,
0,       239,    197,
0,       236,    202,
0,       232,    207,
0,       229,    212,
0,       225,    217,
0,       221,    221,		// 0xa0
0,       217,    225,
0,       212,    229,
0,       207,    232,
0,       202,    236,
0,       197,    239,
0,       192,    241,
0,       186,    244,
0,       180,    246,
0,       174,    248,
0,       168,    250,
0,       162,    252,
0,       155,    253,
0,       149,    254,
0,       142,    254,
0,       135,    255,
0,       128,    255,		// 0xb0
0,       120,    255,
0,       113,    254,
0,       105,    254,
0,       98,     253,
0,       90,     252,
0,       82,     250,
0,       74,     248,
0,       66,     246,
0,       58,     244,
0,       50,     241,
0,       42,     239,
0,       33,     236,
0,       25,     232,
0,       17,     229,
0,       8,      225		// 0xbf
};
#endif
#endif
// provide compatibility with GCC definitions
// sometimes needed, sometimes not. Lets disable them here until we want them
/*
#define PB0 0
#define PB1 1
#define PB2 2
#define PB3 3
#define PB4 4
#define PB5 5
#define PB6 6
#define PB7 7

#define PC0 0
#define PC1 1
#define PC2 2

#define PD0 0
#define PD1 1
#define PD2 2
#define PD3 3
#define PD4 4
#define PD5 5
#define PD6 6
#define PD7 7
*/
// PHASES to pins

#define VH PB1
#define VL PB2
#define WH PB3

#define WL PD3
#define UL PD5
#define UH PD6




#endif
